@@ -35,7 +35,7 @@ BEGIN
 }
 
 # module/package version
-$VERSION = '0.37';
+$VERSION = '0.38';
 
 # file creation mode (octal, a la chmod)
 $FILEMODE = 0660;
@@ -640,8 +640,8 @@ sub openpgp_decrypt
 
     # compose command
     my $cmd = $cfg->OPENPGP_CMD_DECRYPT;
-    $cmd =~ s/__INPUT__/$input_filename/;
-    $cmd =~ s/__OUTPUT__/$output_filename/;
+    $cmd =~ s/__INPUT__/$input_filename/g;
+    $cmd =~ s/__OUTPUT__/$output_filename/g;
     print "<DEBUG> openpgp_decrypt() command: $cmd\n"
         if $cfg->ECS_DEBUG > 0;
 
@@ -680,10 +680,10 @@ sub openpgp_encrypt
     # compose command
     my $keyid = $cfg->GPG_KEYID;
     my $cmd = $cfg->OPENPGP_CMD_ENCRYPT;
-    $cmd =~ s/__INPUT__/$input_filename/;
-    $cmd =~ s/__OUTPUT__/$output_filename/;
-    $cmd =~ s/__RECIPIENT__/$recipient/;
-    $cmd =~ s/__SELF__/$keyid/;
+    $cmd =~ s/__INPUT__/$input_filename/g;
+    $cmd =~ s/__OUTPUT__/$output_filename/g;
+    $cmd =~ s/__RECIPIENT__/$recipient/g;
+    $cmd =~ s/__SELF__/$keyid/g;
     print "<DEBUG> openpgp_encrypt() command: $cmd\n"
         if $cfg->ECS_DEBUG > 0;
 
@@ -712,8 +712,8 @@ sub pgp2_decrypt
 
     # compose command
     my $cmd = $cfg->PGP2_CMD_DECRYPT;
-    $cmd =~ s/__INPUT__/$input_filename/;
-    $cmd =~ s/__OUTPUT__/$output_filename/;
+    $cmd =~ s/__INPUT__/$input_filename/g;
+    $cmd =~ s/__OUTPUT__/$output_filename/g;
     print "<DEBUG> pgp2_decrypt() command: $cmd\n"
         if $cfg->ECS_DEBUG > 0;
 
@@ -754,10 +754,10 @@ sub pgp2_encrypt
     # compose command
     my $keyid = $cfg->PGP_KEYID;
     my $cmd = $cfg->PGP2_CMD_ENCRYPT;
-    $cmd =~ s/__INPUT__/$input_filename/;
-    $cmd =~ s/__OUTPUT__/$output_filename/;
-    $cmd =~ s/__RECIPIENT__/$recipient/;
-    $cmd =~ s/__SELF__/$keyid/;
+    $cmd =~ s/__INPUT__/$input_filename/g;
+    $cmd =~ s/__OUTPUT__/$output_filename/g;
+    $cmd =~ s/__RECIPIENT__/$recipient/g;
+    $cmd =~ s/__SELF__/$keyid/g;
     print "<DEBUG> pgp2_encrypt() command: $cmd\n"
         if $cfg->ECS_DEBUG > 0;
 
