@@ -291,7 +291,7 @@ sub _set_defaults
         '--charset ISO-8859-1 --force-mdc --logger-fd 1 --openpgp ' .
             '--output __OUTPUT__ --passphrase-fd 0 --quiet ' .
                 '--recipient __RECIPIENT__ --recipient __SELF__ --yes ' .
-                    '--sign --encrypt __INPUT__';
+                    '--sign --local-user __SELF__ --encrypt __INPUT__';
     $this->{OPENPGP_CMD_DECRYPT} = '/usr/local/bin/gpg --batch ' .
         '--charset ISO-8859-1 --logger-fd 1 --openpgp --output __OUTPUT__ ' .
             '--passphrase-fd 0 --quiet --yes --decrypt __INPUT__';
